import numpy as np

from tgboost.config.core import config
from tgboost.processing.smiles_manager import SmilesEmbedder, SmilesWrapper


def test_embedder_transformer(sample_input_data):
    # Given
    transformer = SmilesWrapper(
        variables=[config.model_config.smiles_to_extract],
        param_scaler=config.model_config.scaler,
    )

    embedder = SmilesEmbedder(variables=[config.model_config.smiles_to_embed])

    assert sample_input_data.iat[0, 0] == "Oc1cccc(O)c1"

    # When
    transformation = transformer.fit_transform(sample_input_data)
    subject = embedder.fit_transform(transformation)

    reference_smile = round(
        np.array(
            [
                [
                    0.48404604,
                    0.86359125,
                    -0.60287297,
                    2.6454272,
                    0.12341939,
                    0.801101,
                    -4.2641063,
                    0.39290303,
                    1.9293638,
                    1.3272206,
                    -2.4754438,
                    -1.0005014,
                    -2.015557,
                    -0.5296838,
                    -1.203796,
                    0.99383384,
                    1.9129726,
                    -1.3347867,
                    -2.888445,
                    3.0654342,
                    0.7119303,
                    2.3536448,
                    5.3058143,
                    2.175263,
                    -1.6636918,
                    -0.3255021,
                    -0.5454298,
                    -2.3070028,
                    -0.21872841,
                    0.63229454,
                    6.713806,
                    -2.4786625,
                    -1.2261155,
                    -2.705128,
                    0.33106092,
                    1.0245752,
                    0.19391473,
                    1.5649893,
                    2.247974,
                    -0.10521199,
                    -1.5521573,
                    0.12552479,
                    -2.4365304,
                    0.8418141,
                    -4.181456,
                    1.1377783,
                    -0.04745868,
                    1.7252811,
                    -2.3016715,
                    1.1881906,
                    1.4621671,
                    -2.51716,
                    -1.3660113,
                    -2.9488046,
                    -1.7652059,
                    -1.5457782,
                    -2.5247397,
                    -0.31686825,
                    1.0694046,
                    1.975218,
                    -0.3094268,
                    -3.1810062,
                    -0.98962766,
                    2.782696,
                    -3.2993774,
                    0.1962097,
                    3.4717026,
                    0.10576648,
                    -1.7179348,
                    -1.0479432,
                    -0.7166135,
                    1.614287,
                    2.600518,
                    -1.8538284,
                    -0.43579733,
                    2.6237445,
                    -0.76207733,
                    2.6284032,
                    -1.4785367,
                    0.5519529,
                    0.9972758,
                    -0.7003874,
                    -2.7681925,
                    -3.6804507,
                    0.807944,
                    -0.97757626,
                    -3.1653993,
                    1.4313257,
                    1.4733287,
                    -1.0486444,
                    1.1618729,
                    -0.11769348,
                    -1.7331811,
                    1.9643718,
                    0.39244825,
                    0.3344324,
                    1.4020467,
                    0.69312584,
                    1.9147863,
                    0.03351396,
                    -1.8643234,
                    -3.5804296,
                    -3.330836,
                    -4.707723,
                    -0.8438012,
                    -3.560323,
                    0.83366585,
                    2.049786,
                    -0.18997815,
                    -1.9490459,
                    -4.356621,
                    1.0172831,
                    1.4027983,
                    -0.23441379,
                    0.4670951,
                    -1.9642874,
                    1.9308143,
                    2.661518,
                    -2.6047242,
                    0.6178988,
                    -2.4430096,
                    -0.06363229,
                    -0.88673943,
                    3.5142422,
                    0.66620964,
                    -1.5289032,
                    -3.8621757,
                    -0.19243786,
                    -2.3570833,
                    -0.4208667,
                    -0.08333509,
                    0.2026513,
                    4.4661007,
                    4.212225,
                    -0.11467727,
                    3.1771064,
                    3.4039097,
                    0.3007387,
                    2.1268408,
                    0.37777102,
                    2.2535956,
                    0.20904015,
                    0.2059507,
                    0.12882118,
                    0.8830894,
                    2.9712336,
                    0.955179,
                    -0.96372,
                    -0.33955204,
                    0.9587821,
                    3.6836169,
                    0.53304267,
                    3.014451,
                    -0.86734277,
                    0.7046952,
                    0.3927355,
                    -2.9262717,
                    -0.9370082,
                    0.70938873,
                    -0.87215304,
                    -0.5530472,
                    -1.2843963,
                    -1.4147403,
                    0.5938915,
                    0.19650766,
                    -4.7739997,
                    -1.4546082,
                    -1.1500068,
                    1.0675242,
                    0.7856225,
                    -0.48043463,
                    0.5887139,
                    2.9059408,
                    -0.9600739,
                    -0.37616342,
                    -1.346809,
                    1.9732416,
                    -1.2388678,
                    -2.6591055,
                    1.8069372,
                    -1.6117475,
                    2.9596102,
                    0.35672048,
                    3.5181007,
                    2.3334267,
                    -0.38271618,
                    -1.0676807,
                    -0.38600588,
                    -0.16348758,
                    -0.83086646,
                    -0.43057638,
                    0.5623181,
                    0.35507762,
                    0.53744006,
                    0.27062204,
                    -0.16232748,
                    -2.1956003,
                    -2.2602406,
                    -0.14951795,
                    -0.81547266,
                    1.5214247,
                    0.4205856,
                    1.336464,
                    2.8985956,
                    2.372377,
                    -0.76454306,
                    2.4805632,
                    1.4600676,
                    3.9114115,
                    0.18180723,
                    4.3596935,
                    -0.58480287,
                    0.8492509,
                    -2.440106,
                    -0.7834613,
                    -0.1225678,
                    -1.0989436,
                    3.0526803,
                    -3.783911,
                    2.1186097,
                    1.020568,
                    -2.7428176,
                    -1.806401,
                    2.111451,
                    -0.6890428,
                    -2.441083,
                    -1.0388933,
                    -0.07800491,
                    2.6229558,
                    -1.8681159,
                    1.4305544,
                    -0.65596354,
                    -1.3991642,
                    -4.03773,
                    -0.98300123,
                    -2.7584605,
                    0.24629542,
                    -1.2411501,
                    0.10438897,
                    1.7311891,
                    2.049275,
                    0.9274585,
                    2.7303555,
                    1.2088342,
                    -2.0277894,
                    2.2260795,
                    -3.8828583,
                    -2.8018734,
                    1.6933768,
                    0.5388391,
                    -4.9827886,
                    1.4915322,
                    -0.7879816,
                    0.09086801,
                    -4.4647455,
                    0.9250057,
                    1.1053286,
                    -2.2903066,
                    1.0175223,
                    -2.5930326,
                    0.46653372,
                    1.2480166,
                    0.529884,
                    2.1347218,
                    0.24922547,
                    -2.6984448,
                    -3.3263037,
                    0.8394058,
                    -0.8557385,
                    -1.2802974,
                    -0.18406287,
                    3.4395556,
                    -0.20768479,
                    1.0807658,
                    0.32738292,
                    -0.65377903,
                    -0.2605312,
                    -1.0323468,
                    0.45901018,
                    0.7563093,
                    -2.4666417,
                    -1.216153,
                    -5.735626,
                    -0.73209834,
                    -1.172892,
                    1.0542599,
                    -1.3962967,
                    0.09157068,
                    -2.0858068,
                    0.22603439,
                    -1.8651037,
                    3.7111218,
                    3.9071536,
                    0.6699958,
                    -2.9905102,
                    -0.01097535,
                    -3.0149088,
                    -0.711084,
                    -3.611824,
                    0.1545747,
                ]
            ]
        ).sum(),
        4,
    )

    # Then
    assert str(
        round(subject[config.model_config.embedding_list].iat[8, 0].sum(), 4)
    ) == str(reference_smile)
